import tkinter
import customtkinter
from PIL import ImageTk,Image

customtkinter.set_appearance_mode("System")  # Modes: system (default), light, dark
customtkinter.set_default_color_theme("green")  # Themes: blue (default), dark-blue, green


app = customtkinter.CTk()  #creating cutstom tkinter window
app.geometry("600x440")
app.title('Login')



def button_function():
    app.destroy()            # destroy current window and creating new one 
    w = customtkinter.CTk()  
    w.geometry("1280x720")
    w.title('Welcome')
    l1=customtkinter.CTkLabel(master=w, text="Home Page",font=('Century Gothic',60))
    l1.place(relx=0.5, rely=0.5,  anchor=tkinter.CENTER)
    w.mainloop()
    


img1=ImageTk.PhotoImage(Image.open("./assets/pattern.png"))
l1=customtkinter.CTkLabel(master=app,image=img1)
l1.pack()

#creating custom frame
frame=customtkinter.CTkFrame(master=l1, width=320, height=360, corner_radius=15)
frame.place(relx=0.5, rely=0.5, anchor=tkinter.CENTER)

l2=customtkinter.CTkLabel(master=frame, text="Log into your Account",font=('Century Gothic',20))
l2.place(x=50, y=45)

entry1=customtkinter.CTkEntry(master=frame, width=220, placeholder_text='Username')
entry1.place(x=50, y=110)

entry2=customtkinter.CTkEntry(master=frame, width=220, placeholder_text='Password', show="*")
entry2.place(x=50, y=165)

l3=customtkinter.CTkLabel(master=frame, text="Forget password?",font=('Century Gothic',12))
l3.place(x=155,y=195)

#Create custom button
button1 = customtkinter.CTkButton(master=frame, width=220, text="Login", command=button_function, corner_radius=6)
button1.place(x=50, y=240)


img2=customtkinter.CTkImage(Image.open("./assets/Google__G__Logo.svg.webp").resize((20,20), Image.ANTIALIAS))
img3=customtkinter.CTkImage(Image.open("./assets/124010.png").resize((20,20), Image.ANTIALIAS))
button2= customtkinter.CTkButton(master=frame, image=img2, text="Google", width=100, height=20, compound="left", fg_color='white', text_color='black', hover_color='#AFAFAF')
button2.place(x=50, y=290)

button3= customtkinter.CTkButton(master=frame, image=img3, text="Facebook", width=100, height=20, compound="left", fg_color='white', text_color='black', hover_color='#AFAFAF')
button3.place(x=170, y=290)




# You can easily integrate authentication system 

app.mainloop()


# mytool.py
import argparse
import rednerer
from colorama import Style, Fore, Back
import keyboard

def greet(name):
    print(f"Hello, {name}!")

def main():
    parser = argparse.ArgumentParser(
        description="Prismio: A custom CLI tool with multiple commands",
        usage="prismio <command> [options]"
    )

    subparsers = parser.add_subparsers(dest="command", help="Available commands")

    # Add a "greet" command
    greet_parser = subparsers.add_parser("greet", help="Greet a user by name")
    greet_parser.add_argument("name", type=str, help="The name of the person to greet")

    render_parser = subparsers.add_parser("render", help="Render a video With blur-amount")
    render_parser.add_argument("filename", type=str, help="The file / vid path it has to be in your cd")
    render_parser.add_argument("amount", type=int, help="Amount recommended 1 to 8")


    # Add a "version" command
    version_parser = subparsers.add_parser("version", help="Show the version of MyTool")

    # Parse the command-line arguments
    args = parser.parse_args()

    if args.command == "greet":
        greet(args.name)
    elif args.command == "render":
        print(Fore.GREEN + "trying to Render" + Style.RESET_ALL)
        rednerer.render(args.filename, args.amount)
        print("file rendered")
    elif args.command == "version":
        print("MyTool version 1.0")
    else:
        parser.print_help()  # Show help if no command is provided

if __name__ == "__main__":
    main()



from moviepy.editor import VideoFileClip
import numpy as np
import os
from os import getcwd

def add_motion_blur(clip, blur_strength=9):
    """
    Apply a motion blur effect by blending multiple frames for each frame in the clip.
    
    Parameters:
    clip (VideoFileClip): The video clip to apply the motion blur to.
    blur_strength (int): The number of frames to blend together.
    
    Returns:
    VideoFileClip: The video clip with the motion blur effect.
    """
    
    def blur_frame(t):
        """Generate a motion blur effect by averaging frames."""
        frame_list = []
        
        # Add frames before and after the current time
        for offset in range(blur_strength):
            frame_time = max(0, t - offset / clip.fps)  # Time of previous frames
            frame = clip.get_frame(frame_time)
            frame_list.append(frame)
        
        # Average the frames to create a blur effect
        blurred_frame = np.mean(frame_list, axis=0).astype(np.uint8)
        return blurred_frame
    
    # Create a new clip by applying the blur to each frame
    new_clip = clip.fl(lambda gf, t: blur_frame(t), apply_to=['video'])
    
    return new_clip

def render(name, amount):
    """Render

    Args:
        name (str): file name
        amount (int): blur amount
    """
    # Example usage
    # input_video = "to.mp4"
    # output_video = "output_blurred_video.mp4"

    input_video = f"{getcwd()}/{name}"
    output_video = f"{getcwd()}/output_{name}"

    clip = VideoFileClip(input_video)

    # Apply the motion blur
    blurred_clip = add_motion_blur(clip, blur_strength=amount)

    # Write the output video with motion blur
    blurred_clip.write_videofile(output_video, codec='libx264', fps=clip.fps)



# setup.py
from setuptools import setup, find_packages
import setuptools
import os


with open("README.md", "r", encoding="utf-8") as fh:
    long_descriptions = fh.read()

setup(
    name="prismio",  # Name as seen on PyPI
    version="0.0.6",  # Increment this version for updates
    description="For now just for testing",
    long_description=long_descriptions,
    long_description_content_type="text/markdown", 
    author="Parsa",
    author_email="mehr2.business@example.com",  # Optional
    packages=find_packages(),  # Automatically find the RunwayLib packag
    entry_points={
        'console_scripts': [
            'prismio = prismio:main',
        ],
    },
    install_requires=["flask", "colorama", "zenora", "customtkinter", "tqdm", "alive_progress", "moviepy", "rabity", "keyboard"],  # List any dependencies here
    classifiers=[  # Optional, to specify the package's audience
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',  # Specify minimum Python version
)
